@@ -4,8 +4,8 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: helpers.h 2934 2010-07-04 08:44:12Z mbarbon $
-// Copyright:   (c) 2000-2010 Mattia Barbon
+// RCS-ID:      $Id: helpers.h 3038 2011-03-19 14:38:34Z mdootson $
+// Copyright:   (c) 2000-2011 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
@@ -23,6 +23,7 @@
 
 class wxPliUserDataCD;
 class wxPliTreeItemData;
+class wxPliSelfRef;
 struct wxPliEventDescription;
 
 #ifndef WXDLLIMPEXP_FWD_CORE
@@ -333,8 +334,8 @@ wxGBSpan wxPli_sv_2_wxgbspan( pTHX_ SV* scalar );
 #if WXPERL_W_VERSION_GE( 2, 9, 0 )
 class wxPosition;
 wxPosition wxPli_sv_2_wxposition( pTHX_ SV* scalar );
-wxVariant wxPli_sv_2_wxvariant( pTHX_ SV* scalar );
 #endif
+wxVariant FUNCPTR( wxPli_sv_2_wxvariant )( pTHX_ SV* scalar );
 
 wxKeyCode wxPli_sv_2_keycode( pTHX_ SV* scalar );
 
@@ -435,6 +436,9 @@ bool FUNCPTR( wxPli_match_arguments_skipfirst )( pTHX_ const wxPliPrototype& p,
                                                  bool allow_more );
 void FUNCPTR( wxPli_overload_error )( pTHX_ const char* function,
                                       wxPliPrototype* prototypes[] );
+SV* FUNCPTR( wxPli_create_virtual_evthandler )( pTHX_ wxEvtHandler* object,
+                                        const char* classn, bool forcevirtual );
+wxPliSelfRef* FUNCPTR( wxPli_get_selfref )( pTHX_ wxObject* object, bool forcevirtual );
 
 #define WXPLI_BOOT_ONCE_( name, xs ) \
 bool name##_booted = false; \
@@ -527,6 +531,10 @@ struct wxPliHelpers
     void (* m_wxPli_stringarray_push )( pTHX_ const wxArrayString& );
     void (* m_wxPli_overload_error )( pTHX_ const char* function,
                                       wxPliPrototype* prototypes[] );
+    wxVariant (* m_wxPli_sv_2_wxvariant )( pTHX_ SV* scalar );
+    SV* ( * m_wxPli_create_virtual_evthandler )( pTHX_ wxEvtHandler* object,
+                                        const char* cln, bool forcevirtual );
+    wxPliSelfRef* ( * m_wxPli_get_selfref )( pTHX_ wxObject*, bool);
 };
 
 #if wxPERL_USE_THREADS
@@ -570,7 +578,8 @@ wxPliHelpers name = { &wxPli_sv_2_object, \
  wxDEFINE_PLI_HELPER_UNICODE() \
  &wxPli_av_2_arrayint, &wxPli_set_events, &wxPli_av_2_arraystring, \
  &wxPli_objlist_push, &wxPliOutputStream_ctor, &wxPli_stringarray_push, \
- &wxPli_overload_error \
+ &wxPli_overload_error, &wxPli_sv_2_wxvariant, \
+ &wxPli_create_virtual_evthandler, &wxPli_get_selfref \
  }
 
 #if NEEDS_PLI_HELPERS_STRUCT()
@@ -616,6 +625,9 @@ wxPliHelpers name = { &wxPli_sv_2_object, \
   wxPliOutputStream_ctor = name->m_wxPliOutputStream_ctor; \
   wxPli_av_2_stringarray = name->m_wxPli_av_2_stringarray; \
   wxPli_overload_error = name->m_wxPli_overload_error; \
+  wxPli_sv_2_wxvariant = name->m_wxPli_sv_2_wxvariant; \
+  wxPli_create_virtual_evthandler = name->m_wxPli_create_virtual_evthandler; \
+  wxPli_get_selfref = name->m_wxPli_get_selfref; \
   WXPLI_INIT_CLASSINFO();
 
 #else
@@ -624,7 +636,11 @@ wxPliHelpers name = { &wxPli_sv_2_object, \
 
 #endif
 
+#if WXPERL_W_VERSION_GE( 2, 9, 0 )
+int wxCALLBACK ListCtrlCompareFn( long item1, long item2, wxIntPtr comparefn );
+#else
 int wxCALLBACK ListCtrlCompareFn( long item1, long item2, long comparefn );
+#endif
 
 class wxPliUserDataO : public wxObject
 {
